from django import forms

length_choices = [
    (1024, "1024 bytes"),
    (2048, "2048 bytes"),
    (4096, "4096 bytes"),
]

class CaCreateForm(forms.Form):
    title = forms.CharField(max_length=32)
    comment = forms.CharField(max_length=128)

    password = forms.CharField(
        max_length=128,
        widget=forms.PasswordInput(),
        required=True,
    )
    repeat = forms.CharField(
        max_length=128,
        widget=forms.PasswordInput(),
        required=True,
    )
    length = forms.TypedChoiceField(
        choices=length_choices,
        coerce=int,
    )

    country = forms.CharField(
        max_length=128,
        required=False,
    )
    state_or_province = forms.CharField(
        max_length=128,
        required=False,
    )
    locality = forms.CharField(
        max_length=128,
        required=False,
    )
    organization = forms.CharField(
        max_length=128,
        required=False,
    )
    common_name = forms.CharField(
        max_length=128,
        required=True,
    )

    public = forms.BooleanField(required=False)

    def clean(self):
        """Custom validation to match passwords"""
        cleaned_data = super().clean()

        password = cleaned_data.get('password')
        repeat = cleaned_data.get('repeat')

        if password and repeat:
            if password != repeat:
                raise forms.ValidationError("The two password fields must match")

        return cleaned_data

class CsrCreateForm(forms.Form):
    csr_pem = forms.FileField()

class CsrCreateHelperForm(forms.Form):
    csr_pem = forms.CharField()

class CsrResolveForm(forms.Form):
    password = forms.CharField(
        max_length=128,
        widget=forms.PasswordInput()
    )
    days = forms.IntegerField(initial=365)
